# Moonchart
This package provides backtest performance analysis and charting for [QuantRocket](https://www.quantrocket.com).

For installation and usage documentation, please visit: https://www.quantrocket.com/docs/

## License

Moonchart is distributed under the Apache 2.0 License. See the LICENSE file in the release for details.
